import React, {useRef} from "react";
import "../../style/player.css";
import RemoveIcon from "../../assets/icon/remove.svg";
import Draggable, {DraggableBounds} from "react-draggable";
import {PlayerPiece} from "./PlayerPiece";

export interface PlayerOptions {
    pos: string,
    x: number,
    y: number,
    bounds: DraggableBounds,
    onRemove: () => void
}

/**
 * A player that is placed on the court, which can be selected, and moved in the associated bounds
 * */
export default function CourtPlayer({pos, x, y, bounds, onRemove}: PlayerOptions) {

    const ref = useRef<HTMLDivElement>(null);
    return (
        <Draggable
            handle={".player-piece"}
            nodeRef={ref}
            bounds={bounds}
            defaultPosition={{x: x, y: y}}
        >
            <div ref={ref}
                 className={"player"}
                 style={{
                     position: "absolute",
                 }}>

                <div tabIndex={0}
                     className="player-content"
                     onKeyUp={e => {
                         if (e.key == "Delete")
                             onRemove()
                     }}>
                    <div className="player-selection-tab">
                        <RemoveIcon
                            className="player-selection-tab-remove"
                            onClick={() => onRemove()}/>
                    </div>
                    <PlayerPiece text={pos}/>
                </div>
            </div>

        </Draggable>

    )
}